import { Observable } from 'rxjs';
import { Router } from '@angular/router';
import { BluiAuthConfig } from '../../services/config/auth-config';
import * as i0 from "@angular/core";
export declare type SecurityContext = {
    /**
     * Email of the authenticated user.
     */
    email?: string;
    /**
     * UserId of the authenticated user (may be an email).
     */
    userId?: string;
    /**
     * Information for a user who wants to be remembered upon logout.
     */
    rememberMeDetails: {
        /**
         * Email address to show in the email field of Login after logout.
         */
        email?: string;
        /**
         * When true, the user's email will be in the email field of Login.
         */
        rememberMe?: boolean;
    };
    /**
     * True: The security state is being loaded (all other fields are invalid).
     * False: The security state has been loaded.
     */
    isLoading: boolean;
    /**
     * Message to display below the loading spinner.
     */
    loadingMessage: string;
    /**
     * True: The user is authenticated and the application is shown (or the Change Password interface).
     * False: The user is not authenticated and the Authentication User Interface is shown.
     */
    isAuthenticatedUser: boolean;
    /**
     * Save email address during registration process
     */
    registrationEmail: string;
    /**
     * Save password during registration process
     */
    registrationPassword: string;
};
export declare type RememberMeData = {
    user: string;
    rememberMe: boolean;
};
export declare class BluiAuthSecurityService {
    private readonly _router;
    private readonly _bluiAuthConfig;
    private readonly securityStateObs;
    private isFirstRouteCaptured;
    private securityState;
    constructor(_router: Router, _bluiAuthConfig: BluiAuthConfig);
    inferOnAuthenticatedRoute(defaultHomeRoute?: string): void;
    updateSecurityState(newState: Partial<SecurityContext>): void;
    setSecurityState(newSecurityState: SecurityContext): void;
    getSecurityState(): SecurityContext;
    securityStateChanges(): Observable<SecurityContext>;
    setLoading(isLoading: boolean): void;
    setLoadingMessage(loadingMessage: string): void;
    clearLoadingMessage(): void;
    onUserAuthenticated(email: string, password: string, rememberMe: boolean): void;
    onUserNotAuthenticated(rememberMeDetails?: RememberMeData): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<BluiAuthSecurityService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<BluiAuthSecurityService>;
}
